package org.neo4j.cineasts.movieimport;

import org.neo4j.cineasts.domain.Movie;
import org.neo4j.cineasts.domain.Person;
import org.neo4j.cineasts.domain.Roles;
import org.springframework.stereotype.Component;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class MovieDbJsonMapper {

    public void mapToMovie(Map data, Movie movie) {
        try {
            movie.setTitle((String) data.get("name"));
            movie.setLanguage((String) data.get("language"));
            movie.setImdbId((String) data.get("imdb_id"));
            movie.setTagline((String) data.get("tagline"));
            movie.setDescription(limit((String) data.get("overview"), 500));
            movie.setReleaseDate(toDate(data, "released", "yyyy-MM-dd"));
            movie.setRuntime((Integer) data.get("runtime"));
            movie.setHomepage((String) data.get("homepage"));
            movie.setTrailer((String) data.get("trailer"));
            movie.setGenre(extractFirst(data, "genres", "name"));
            movie.setStudio(extractFirst(data,"studios", "name"));
            movie.setVersion((Integer)data.get("version"));
            movie.setLastModified(toDate(data,"last_modified_at","yyyy-MM-dd HH:mm:ss"));
            movie.setImageUrl(selectImageUrl((List<Map>) data.get("posters"), "poster", "mid"));
        } catch (Exception e) {
            throw new MovieDbException("Failed to map json for movie", e);
        }
    }

    private String selectImageUrl(List<Map> data, final String type, final String size) {
        if (data==null) return null;
        for (Map entry : data) {
            Map image = (Map) entry.get("image");
            if (image.get("type").equals(type) && image.get("size").equals(size)) return (String) image.get("url");
        }
        return null;
    }


    private String extractFirst(Map data, String field, String property) {
        List<Map> inner = (List<Map>) data.get(field);
        if (inner == null || inner.isEmpty()) return null;
        return (String) inner.get(0).get(property);
    }

    private Date toDate(Map data, String field, final String pattern) throws ParseException {
        try {
            String dateString = (String) data.get(field);
            if (dateString == null || dateString.isEmpty()) return null;
            return new SimpleDateFormat(pattern).parse(dateString);
        } catch (Exception e) {
            return null;
        }
    }

    /*
   [{"popularity":3,
"translated":true,
"adult":false,
"language":"en",
"original_name":"[Rec]",
"name":"[Rec]",
"alternative_name":"[REC]",
"movie_type":"movie",
"id":8329,
"imdb_id":"tt1038988",
"url":"http://www.themoviedb.org/movie/8329",
"votes":11,
"rating":7.2,
"status":"Released",
"tagline":"One Witness. One Camera",
"certification":"R",
"overview":"\"REC\" turns on a young TV reporter and her cameraman who cover the night shift at the local fire station. Receiving a call from an old lady trapped in her house,
they reach her building to hear horrifying screams -- which begin a long nightmare and a uniquely dramatic TV report.",
"keywords":["terror",
"lebende leichen",
"obsession",
"camcorder",
"firemen",
"reality tv ",
"bite",
"cinematographer",
"attempt to escape",
"virus",
"lodger",
"live-reportage",
"schwerverletzt"],
"released":"2007-08-29",
"runtime":78,
"budget":0,
"revenue":0,
"homepage":"http://www.3l-filmverleih.de/rec",
"trailer":"http://www.youtube.com/watch?v=YQUkX_XowqI",
"genres":[{"type":"genre",
"url":"http://themoviedb.org/genre/horror",
"name":"Horror",
"id":27}],
"studios":[{"url":"http://www.themoviedb.org/company/2270",
"name":"Filmax Group",
"id":2270}],
"languages_spoken":[{"code":"es",
"name":"Spanish",
"native_name":"Espa\u00f1ol"}],
"countries":[{"code":"ES",
"name":"Spain",
"url":"http://www.themoviedb.org/country/es"}],
"posters":[{"image":{"type":"poster",
"size":"original",
"height":1000,
"width":706,
"url":"http://cf1.imgobject.com/posters/3a0/4cc8df415e73d650240003a0/rec-original.jpg",
"id":"4cc8df415e73d650240003a0"}},
{"image":{"type":"poster",
"size":"mid",
"height":708,
"width":500,
"url":"http://cf1.imgobject.com/posters/3a0/4cc8df415e73d650240003a0/rec-mid.jpg",
"id":"4cc8df415e73d650240003a0"}},
{"image":{"type":"poster",
"size":"cover",
"height":262,
"width":185,
"url":"http://cf1.imgobject.com/posters/3a0/4cc8df415e73d650240003a0/rec-cover.jpg",
"id":"4cc8df415e73d650240003a0"}},
{"image":{"type":"poster",
"size":"thumb",
"height":130,
"width":92,
"url":"http://cf1.imgobject.com/posters/3a0/4cc8df415e73d650240003a0/rec-thumb.jpg",
"id":"4cc8df415e73d650240003a0"}},
{"image":{"type":"poster",
"size":"original",
"height":1000,
"width":711,
"url":"http://cf1.imgobject.com/posters/1e7/4bc92117017a3c57fe00d1e7/rec-original.jpg",
"id":"4bc92117017a3c57fe00d1e7"}},
{"image":{"type":"poster",
"size":"mid",
"height":703,
"width":500,
"url":"http://cf1.imgobject.com/posters/1e7/4bc92117017a3c57fe00d1e7/rec-mid.jpg",
"id":"4bc92117017a3c57fe00d1e7"}},
{"image":{"type":"poster",
"size":"cover",
"height":260,
"width":185,
"url":"http://cf1.imgobject.com/posters/1e7/4bc92117017a3c57fe00d1e7/rec-cover.jpg",
"id":"4bc92117017a3c57fe00d1e7"}},
{"image":{"type":"poster",
"size":"thumb",
"height":129,
"width":92,
"url":"http://cf1.imgobject.com/posters/1e7/4bc92117017a3c57fe00d1e7/rec-thumb.jpg",
"id":"4bc92117017a3c57fe00d1e7"}},
{"image":{"type":"poster",
"size":"original",
"height":1500,
"width":1000,
"url":"http://cf1.imgobject.com/posters/1ec/4bc92118017a3c57fe00d1ec/rec-original.jpg",
"id":"4bc92118017a3c57fe00d1ec"}},
{"image":{"type":"poster",
"size":"mid",
"height":750,
"width":500,
"url":"http://cf1.imgobject.com/posters/1ec/4bc92118017a3c57fe00d1ec/rec-mid.jpg",
"id":"4bc92118017a3c57fe00d1ec"}},
{"image":{"type":"poster",
"size":"cover",
"height":278,
"width":185,
"url":"http://cf1.imgobject.com/posters/1ec/4bc92118017a3c57fe00d1ec/rec-cover.jpg",
"id":"4bc92118017a3c57fe00d1ec"}},
{"image":{"type":"poster",
"size":"thumb",
"height":138,
"width":92,
"url":"http://cf1.imgobject.com/posters/1ec/4bc92118017a3c57fe00d1ec/rec-thumb.jpg",
"id":"4bc92118017a3c57fe00d1ec"}},
{"image":{"type":"poster",
"size":"original",
"height":1429,
"width":1000,
"url":"http://cf1.imgobject.com/posters/1f1/4bc92118017a3c57fe00d1f1/rec-original.jpg",
"id":"4bc92118017a3c57fe00d1f1"}},
{"image":{"type":"poster",
"size":"mid",
"height":715,
"width":500,
"url":"http://cf1.imgobject.com/posters/1f1/4bc92118017a3c57fe00d1f1/rec-mid.jpg",
"id":"4bc92118017a3c57fe00d1f1"}},
{"image":{"type":"poster",
"size":"cover",
"height":265,
"width":185,
"url":"http://cf1.imgobject.com/posters/1f1/4bc92118017a3c57fe00d1f1/rec-cover.jpg",
"id":"4bc92118017a3c57fe00d1f1"}},
{"image":{"type":"poster",
"size":"thumb",
"height":132,
"width":92,
"url":"http://cf1.imgobject.com/posters/1f1/4bc92118017a3c57fe00d1f1/rec-thumb.jpg",
"id":"4bc92118017a3c57fe00d1f1"}},
{"image":{"type":"poster",
"size":"original",
"height":1125,
"width":800,
"url":"http://cf1.imgobject.com/posters/1f6/4bc92118017a3c57fe00d1f6/rec-original.jpg",
"id":"4bc92118017a3c57fe00d1f6"}},
{"image":{"type":"poster",
"size":"mid",
"height":703,
"width":500,
"url":"http://cf1.imgobject.com/posters/1f6/4bc92118017a3c57fe00d1f6/rec-mid.jpg",
"id":"4bc92118017a3c57fe00d1f6"}},
{"image":{"type":"poster",
"size":"cover",
"height":260,
"width":185,
"url":"http://cf1.imgobject.com/posters/1f6/4bc92118017a3c57fe00d1f6/rec-cover.jpg",
"id":"4bc92118017a3c57fe00d1f6"}},
{"image":{"type":"poster",
"size":"thumb",
"height":129,
"width":92,
"url":"http://cf1.imgobject.com/posters/1f6/4bc92118017a3c57fe00d1f6/rec-thumb.jpg",
"id":"4bc92118017a3c57fe00d1f6"}}],
"backdrops":[{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/1df/4bc92117017a3c57fe00d1df/rec-original.jpg",
"id":"4bc92117017a3c57fe00d1df"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/1df/4bc92117017a3c57fe00d1df/rec-poster.jpg",
"id":"4bc92117017a3c57fe00d1df"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/1df/4bc92117017a3c57fe00d1df/rec-thumb.jpg",
"id":"4bc92117017a3c57fe00d1df"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/1d7/4bc92113017a3c57fe00d1d7/rec-original.jpg",
"id":"4bc92113017a3c57fe00d1d7"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/1d7/4bc92113017a3c57fe00d1d7/rec-poster.jpg",
"id":"4bc92113017a3c57fe00d1d7"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/1d7/4bc92113017a3c57fe00d1d7/rec-thumb.jpg",
"id":"4bc92113017a3c57fe00d1d7"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/1e3/4bc92117017a3c57fe00d1e3/rec-original.jpg",
"id":"4bc92117017a3c57fe00d1e3"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/1e3/4bc92117017a3c57fe00d1e3/rec-poster.jpg",
"id":"4bc92117017a3c57fe00d1e3"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/1e3/4bc92117017a3c57fe00d1e3/rec-thumb.jpg",
"id":"4bc92117017a3c57fe00d1e3"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/1d3/4bc92113017a3c57fe00d1d3/rec-original.jpg",
"id":"4bc92113017a3c57fe00d1d3"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/1d3/4bc92113017a3c57fe00d1d3/rec-poster.jpg",
"id":"4bc92113017a3c57fe00d1d3"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/1d3/4bc92113017a3c57fe00d1d3/rec-thumb.jpg",
"id":"4bc92113017a3c57fe00d1d3"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/1db/4bc92114017a3c57fe00d1db/rec-original.jpg",
"id":"4bc92114017a3c57fe00d1db"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/1db/4bc92114017a3c57fe00d1db/rec-poster.jpg",
"id":"4bc92114017a3c57fe00d1db"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/1db/4bc92114017a3c57fe00d1db/rec-thumb.jpg",
"id":"4bc92114017a3c57fe00d1db"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/6f4/4d0e39c25e73d637100016f4/rec-original.jpg",
"id":"4d0e39c25e73d637100016f4"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/6f4/4d0e39c25e73d637100016f4/rec-poster.jpg",
"id":"4d0e39c25e73d637100016f4"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/6f4/4d0e39c25e73d637100016f4/rec-thumb.jpg",
"id":"4d0e39c25e73d637100016f4"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/567/4d0e39dd5e73d6370a001567/rec-original.jpg",
"id":"4d0e39dd5e73d6370a001567"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/567/4d0e39dd5e73d6370a001567/rec-poster.jpg",
"id":"4d0e39dd5e73d6370a001567"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/567/4d0e39dd5e73d6370a001567/rec-thumb.jpg",
"id":"4d0e39dd5e73d6370a001567"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/58a/4d0e39fb5e73d6371c00158a/rec-original.jpg",
"id":"4d0e39fb5e73d6371c00158a"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/58a/4d0e39fb5e73d6371c00158a/rec-poster.jpg",
"id":"4d0e39fb5e73d6371c00158a"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/58a/4d0e39fb5e73d6371c00158a/rec-thumb.jpg",
"id":"4d0e39fb5e73d6371c00158a"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/5f4/4d0e3a185e73d6370e0015f4/rec-original.jpg",
"id":"4d0e3a185e73d6370e0015f4"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/5f4/4d0e3a185e73d6370e0015f4/rec-poster.jpg",
"id":"4d0e3a185e73d6370e0015f4"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/5f4/4d0e3a185e73d6370e0015f4/rec-thumb.jpg",
"id":"4d0e3a185e73d6370e0015f4"}},
{"image":{"type":"backdrop",
"size":"original",
"height":1080,
"width":1920,
"url":"http://cf1.imgobject.com/backdrops/67f/4d0e3a395e73d6371600167f/rec-original.jpg",
"id":"4d0e3a395e73d6371600167f"}},
{"image":{"type":"backdrop",
"size":"poster",
"height":439,
"width":780,
"url":"http://cf1.imgobject.com/backdrops/67f/4d0e3a395e73d6371600167f/rec-poster.jpg",
"id":"4d0e3a395e73d6371600167f"}},
{"image":{"type":"backdrop",
"size":"thumb",
"height":169,
"width":300,
"url":"http://cf1.imgobject.com/backdrops/67f/4d0e3a395e73d6371600167f/rec-thumb.jpg",
"id":"4d0e3a395e73d6371600167f"}}],
"cast":[{"name":"Manuela Velasco",
"job":"Actor",
"department":"Actors",
"character":"Angela Vidal",
"id":34793,
"order":0,
"cast_id":1,
"url":"http://www.themoviedb.org/person/34793",
"profile":"http://cf1.imgobject.com/profiles/390/4c0157fa017a3c702d001390/manuela-velasco-thumb.jpg"},
{"name":"Carlos Lasarte",
"job":"Actor",
"department":"Actors",
"character":"C\u00e9sar",
"id":54519,
"order":2,
"cast_id":3,
"url":"http://www.themoviedb.org/person/54519",
"profile":"http://cf1.imgobject.com/profiles/ba6/4d27aa297b9aa134d3001ba6/carlos-lasarte-thumb.jpg"},
{"name":"Pablo Rosso",
"job":"Actor",
"department":"Actors",
"character":"Marcos",
"id":54520,
"order":3,
"cast_id":4,
"url":"http://www.themoviedb.org/person/54520",
"profile":""},
{"name":"David Vert",
"job":"Actor",
"department":"Actors",
"character":"Alex",
"id":54521,
"order":4,
"cast_id":5,
"url":"http://www.themoviedb.org/person/54521",
"profile":"http://cf1.imgobject.com/profiles/c7e/4d27aad57b9aa134cb001c7e/david-vert-thumb.jpg"},
{"name":"Vicente Gil",
"job":"Actor",
"department":"Actors",
"character":"Polizist",
"id":54522,
"order":5,
"cast_id":6,
"url":"http://www.themoviedb.org/person/54522",
"profile":"http://cf1.imgobject.com/profiles/c86/4d27ab237b9aa134cb001c86/vicente-gil-thumb.jpg"},
{"name":"Martha Carbonell",
"job":"Actor",
"department":"Actors",
"character":"Frau Izquierdo",
"id":54523,
"order":6,
"cast_id":7,
"url":"http://www.themoviedb.org/person/54523",
"profile":"http://cf1.imgobject.com/profiles/c90/4d27ab777b9aa134cb001c90/martha-carbonell-thumb.jpg"},
{"name":"Carlos Vicente",
"job":"Actor",
"department":"Actors",
"character":"Guillem",
"id":54524,
"order":7,
"cast_id":8,
"url":"http://www.themoviedb.org/person/54524",
"profile":"http://cf1.imgobject.com/profiles/b0f/4d27abcc7b9aa134cf001b0f/carlos-vicente-thumb.jpg"},
{"name":"Ferran Terraza",
"job":"Actor",
"department":"Actors",
"character":"Manu",
"id":54532,
"order":8,
"cast_id":22,
"url":"http://www.themoviedb.org/person/54532",
"profile":"http://cf1.imgobject.com/profiles/129/4c4bfbab7b9aa1237f000129/ferran-terraza-thumb.jpg"},
{"name":"Jorge Yamam",
"job":"Actor",
"department":"Actors",
"character":"Sergio",
"id":147878,
"order":9,
"cast_id":23,
"url":"http://www.themoviedb.org/person/147878",
"profile":"http://cf1.imgobject.com/profiles/cbb/4d27ac677b9aa134dc001cbb/jorge-yamam-thumb.jpg"},
{"name":"Jaume Balaguer\u00f3",
"job":"Director",
"department":"Directing",
"character":"",
"id":54525,
"order":0,
"cast_id":9,
"url":"http://www.themoviedb.org/person/54525",
"profile":""},
{"name":"Paco Plaza",
"job":"Director",
"department":"Directing",
"character":"",
"id":54526,
"order":0,
"cast_id":10,
"url":"http://www.themoviedb.org/person/54526",
"profile":""},
{"name":"Jaume Balaguer\u00f3",
"job":"Screenplay",
"department":"Writing",
"character":"",
"id":54525,
"order":0,
"cast_id":11,
"url":"http://www.themoviedb.org/person/54525",
"profile":""},
{"name":"Paco Plaza",
"job":"Screenplay",
"department":"Writing",
"character":"",
"id":54526,
"order":0,
"cast_id":12,
"url":"http://www.themoviedb.org/person/54526",
"profile":""},
{"name":"Luis Berdejo",
"job":"Screenplay",
"department":"Writing",
"character":"",
"id":54527,
"order":0,
"cast_id":13,
"url":"http://www.themoviedb.org/person/54527",
"profile":""},
{"name":"Julio Fern\u00e1ndez",
"job":"Producer",
"department":"Production",
"character":"",
"id":17083,
"order":0,
"cast_id":14,
"url":"http://www.themoviedb.org/person/17083",
"profile":""},
{"name":"Carlos Fern\u00e1ndez",
"job":"Executive Producer",
"department":"Production",
"character":"",
"id":37950,
"order":0,
"cast_id":15,
"url":"http://www.themoviedb.org/person/37950",
"profile":""},
{"name":"Alberto Marini",
"job":"Producer",
"department":"Production",
"character":"",
"id":54528,
"order":0,
"cast_id":16,
"url":"http://www.themoviedb.org/person/54528",
"profile":""},
{"name":"Pablo Rosso",
"job":"Director of Photography",
"department":"Camera",
"character":"",
"id":54520,
"order":0,
"cast_id":17,
"url":"http://www.themoviedb.org/person/54520",
"profile":""},
{"name":"Gemma Fauria",
"job":"Set Designer",
"department":"Art",
"character":"",
"id":54529,
"order":0,
"cast_id":18,
"url":"http://www.themoviedb.org/person/54529",
"profile":""},
{"name":"David Gallart",
"job":"Editor",
"department":"Editing",
"character":"",
"id":28500,
"order":0,
"cast_id":19,
"url":"http://www.themoviedb.org/person/28500",
"profile":""},
{"name":"Xavier Mas",
"job":"Sound Designer",
"department":"Sound",
"character":"",
"id":54530,
"order":0,
"cast_id":20,
"url":"http://www.themoviedb.org/person/54530",
"profile":""},
{"name":"Gl\u00f2ria Viguer",
"job":"Costume Design",
"department":"Costume \u0026 Make-Up",
"character":"",
"id":54531,
"order":0,
"cast_id":21,
"url":"http://www.themoviedb.org/person/54531",
"profile":""}],
"version":150,
"last_modified_at":"2011-02-20 23:16:57"}]
    */

    public void mapToPerson(Map data, Person person) {
        try {
            person.setName((String) data.get("name"));
            person.setBirthday(toDate(data, "birthday", "yyyy-MM-dd"));
            person.setBirthplace((String) data.get("birthplace"));
            String biography = (String) data.get("biography");
            person.setBiography(limit(biography,500));
            person.setVersion((Integer) data.get("version"));
            person.setProfileImageUrl(selectImageUrl((List<Map>) data.get("profile"), "profile", "profile"));
            person.setLastModified(toDate(data,"last_modified_at","yyyy-MM-dd HH:mm:ss"));
        } catch (Exception e) {
            throw new MovieDbException("Failed to map json for person", e);
        }
    }

    private String limit(String text, int limit) {
        if (text==null || text.length() < limit) return text;
        return text.substring(0,limit);
    }

/*
    [{"popularity":3,
"name":"Glenn Strange",
"known_as":[{"name":"George Glenn Strange"},
{"name":"Glen Strange"},
{"name":"Glen 'Peewee' Strange"},
{"name":"Peewee Strange"},
{"name":"'Peewee' Strange"}],
"id":30112,
"biography":"",
"known_movies":4,
"birthday":"1899-08-16",
"birthplace":"Weed,
 New Mexico,
 USA",
"url":"http://www.themoviedb.org/person/30112",
"filmography":[{"name":"Bud Abbott Lou Costello Meet Frankenstein",
"id":3073,
"job":"Actor",
"department":"Actors",
"character":"The Frankenstein Monster",
"cast_id":23,
"url":"http://www.themoviedb.org/movie/3073",
"poster":"http://cf1.imgobject.com/posters/4ca/4bc9185d017a3c57fe0094ca/bud-abbott-lou-costello-meet-frankenstein-cover.jpg",
"adult":false,
"release":"1948-06-15"},
{"name":"Arizona Days (1937)",
"id":22367,
"job":"Actor",
"department":"Actors",
"character":"Henchman Pete ",
"cast_id":12,
"url":"http://www.themoviedb.org/movie/22367",
"poster":"",
"adult":false,
"release":"1937-01-30"},
{"name":"House of Dracula",
"id":30793,
"job":"Actor",
"department":"Actors",
"character":"The Frankenstein Monster",
"cast_id":3,
"url":"http://www.themoviedb.org/movie/30793",
"poster":"http://cf1.imgobject.com/posters/7cf/4bc97660017a3c57fe0367cf/house-of-dracula-cover.jpg",
"adult":false,
"release":"1945-01-01"},
{"name":"The Fargo Kid",
"id":38704,
"job":"Actor",
"department":"Actors",
"character":"Sheriff Dave",
"cast_id":24,
"url":"http://www.themoviedb.org/movie/38704",
"poster":"http://cf1.imgobject.com/posters/04e/4d74018a5e73d6021d00004e/the-fargo-kid-cover.jpg",
"adult":false,
"release":"1940-12-06"}],
"profile":[],
"version":19,
"last_modified_at":"2011-03-07 13:02:35"}]
*/


    public Roles mapToRole(String roleString) {
        if (roleString.equals("Actor")) {
            return Roles.ACTS_IN;
        }
        if (roleString.equals("Director")) {
            return Roles.DIRECTED;
        }
        return null;
    }
}
